@@ -184,13 +184,27 @@ io_error (SoupSocket *sock, SoupMessage *msg)
 	soup_message_io_finished (msg);
 }
 
+/* Reads data from io->sock into io->read_meta_buf up until @boundary.
+ * (This function is used to read metadata, and read_body_chunk() is
+ * used to read the message body contents.)
+ *
+ * read_metadata, read_body_chunk, and write_data all use the same
+ * convention for return values: if they return %TRUE, it means
+ * they've completely finished the requested read/write, and the
+ * caller should move on to the next step. If they return %FALSE, it
+ * means that either (a) the socket returned SOUP_SOCKET_WOULD_BLOCK,
+ * so the caller should give up for now and wait for the socket to
+ * emit a signal, or (b) the socket returned an error, and io_error()
+ * was called to process it and cancel the I/O. So either way, if the
+ * function returns %FALSE, the caller should return immediately.
+ */
 static gboolean
 read_metadata (SoupMessage *msg, const char *boundary)
 {
 	SoupMessagePrivate *priv = SOUP_MESSAGE_GET_PRIVATE (msg);
 	SoupMessageIOData *io = priv->io_data;
 	SoupSocketIOStatus status;
-	char read_buf[RESPONSE_BLOCK_SIZE];
+	guchar read_buf[RESPONSE_BLOCK_SIZE];
 	guint boundary_len = strlen (boundary);
 	gsize nread;
 	gboolean done;
@@ -218,13 +232,23 @@ read_metadata (SoupMessage *msg, const char *boundary)
 	return TRUE;
 }
 
+/* Reads as much message body data as is available on io->sock (but no
+ * further than the end of the current message body or chunk). On a
+ * successful read, emits "got_chunk" (possibly multiple times), and
+ * if io->read_buf is non-%NULL (meaning that the message doesn't have
+ * %SOUP_MESSAGE_OVERWRITE_CHUNKS set), the data will be appended to
+ * it.
+ *
+ * See the note at read_metadata() for an explanation of the return
+ * value.
+ */
 static gboolean
 read_body_chunk (SoupMessage *msg)
 {
 	SoupMessagePrivate *priv = SOUP_MESSAGE_GET_PRIVATE (msg);
 	SoupMessageIOData *io = priv->io_data;
 	SoupSocketIOStatus status;
-	char read_buf[RESPONSE_BLOCK_SIZE];
+	guchar read_buf[RESPONSE_BLOCK_SIZE];
 	guint len = sizeof (read_buf);
 	gboolean read_to_eof = (io->read_encoding == SOUP_TRANSFER_UNKNOWN);
 	gsize nread;
@@ -241,7 +265,7 @@ read_body_chunk (SoupMessage *msg)
 				break;
 
 			io->read_body->owner  = SOUP_BUFFER_STATIC;
-			io->read_body->body   = read_buf;
+			io->read_body->body   = (char *)read_buf;
 			io->read_body->length = nread;
 
 			SOUP_MESSAGE_IO_PREPARE_FOR_CALLBACK;
@@ -272,6 +296,9 @@ read_body_chunk (SoupMessage *msg)
 	return TRUE;
 }
 
+/* Attempts to write @len bytes from @data. See the note at
+ * read_metadata() for an explanation of the return value.
+ */
 static gboolean
 write_data (SoupMessage *msg, const char *data, guint len)
 {
@@ -346,6 +373,8 @@ io_write (SoupSocket *sock, SoupMessage *msg)
 	SoupMessagePrivate *priv = SOUP_MESSAGE_GET_PRIVATE (msg);
 	SoupMessageIOData *io = priv->io_data;
 
+	g_return_if_fail (io->write_state != SOUP_MESSAGE_IO_STATE_DONE);
+
  write_more:
 	switch (io->write_state) {
 	case SOUP_MESSAGE_IO_STATE_NOT_STARTED:
@@ -522,6 +551,8 @@ io_read (SoupSocket *sock, SoupMessage *msg)
 	SoupMessageIOData *io = priv->io_data;
 	guint status;
 
+	g_return_if_fail (io->read_state != SOUP_MESSAGE_IO_STATE_DONE);
+
  read_more:
 	switch (io->read_state) {
 	case SOUP_MESSAGE_IO_STATE_NOT_STARTED:
@@ -534,7 +565,7 @@ io_read (SoupSocket *sock, SoupMessage *msg)
 
 		io->read_meta_buf->len -= SOUP_MESSAGE_IO_EOL_LEN;
 		io->read_meta_buf->data[io->read_meta_buf->len] = '\0';
-		status = io->parse_headers_cb (msg, io->read_meta_buf->data,
+		status = io->parse_headers_cb (msg, (char *)io->read_meta_buf->data,
 					       io->read_meta_buf->len,
 					       &io->read_encoding,
 					       &io->read_length,
@@ -604,7 +635,7 @@ io_read (SoupSocket *sock, SoupMessage *msg)
 	got_body:
 		if (io->read_buf) {
 			io->read_body->owner = SOUP_BUFFER_SYSTEM_OWNED;
-			io->read_body->body = io->read_buf->data;
+			io->read_body->body = (char *)io->read_buf->data;
 			io->read_body->length = io->read_buf->len;
 
 			g_byte_array_free (io->read_buf, FALSE);
@@ -623,7 +654,7 @@ io_read (SoupSocket *sock, SoupMessage *msg)
 		if (!read_metadata (msg, SOUP_MESSAGE_IO_EOL))
 			return;
 
-		io->read_length = strtoul (io->read_meta_buf->data, NULL, 16);
+		io->read_length = strtoul ((char *)io->read_meta_buf->data, NULL, 16);
 		g_byte_array_set_size (io->read_meta_buf, 0);
 
 		if (io->read_length > 0)
